<?php 

// Change user info
$lang['title'] = 'Edit user account';
$lang['ln_photo'] = 'Photo';
$lang['ln_birth_date'] = 'Date of birth';
$lang['Default language'] = 'Default language';
$lang['ln_email'] = 'Email';
$lang['ln_name'] = 'First name';
$lang['ln_surname'] = 'Last name';
$lang['ln_about'] = 'About me';
